#
# spec file for package python-pyvips
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pyvips
Version:        2.2.3
Release:        1.4
Summary:        Python bindings for VIPS image processing library
License:        MIT
URL:            https://github.com/libvips/pyvips
Source0:        https://pypi.io/packages/source/p/pyvips/pyvips-%{version}.tar.gz
BuildRequires:  %{python_module cffi >= 1.0.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cffi >= 1.0.0
BuildArch:      noarch
%python_subpackages

%description
This package contains the Python bindings for the VIPS library.

%prep
%autosetup -n pyvips-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# NOTE: tests are not present in the pypi tarball

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/pyvips
%{python_sitelib}/pyvips-%{version}-py%{python_version}.egg-info

%changelog
* Thu Jun  6 2024 Dirk Müller <dmueller@suse.com>
- update to 2.2.3:
  * Fix -Wincompatible-function-pointer-types warning on Clang
  * Fix flake8 warnings
  * new_from_source keeps a ref to the source
  * improve generation of enums.py
  * Ensure compatibility with a single shared libvips library
* Fri Jan  5 2024 Dirk Müller <dmueller@suse.com>
- update to 2.2.2:
  * fix with libvips nodeprecated
  * update README notes for py3.8+ on win
  * fix VipsObect.print_all()
  * add split, join, annotate animation examples
  * work around broken ffi bool type
  * flag classes are now integer-valued so you can OR them
  * update docs for 8.15
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to Version 2.2.1 (released 12 Jun 2022)
  add seek and end handlers for TargetCustom [jcupitt]
  add block_untrusted_set, operation_block_set [jcupitt]
  update for libvips 8.13 [jcupitt]
* Thu May  7 2020 aloisio@gmx.com
- Update to version 2.1.12
  * update enums.py [tony612]
  * add gen-enums.py [jcupitt]
  * improve custom source/target types [jcupitt]
  * revise types for set_blob to fix exception with old libvips [jcupitt]
  * fix 32-bit support [dqxpb]
  * remove pytest-runner from pipy deps [lgbaldoni]
  * add watermark with image example [jcupitt]
* Mon May  4 2020 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v2.1.11)
